@@ -213,6 +213,7 @@ __all__ = (
     "FlowLogsResourceTypeType",
     "FpgaImageAttributeNameType",
     "FpgaImageStateCodeType",
+    "GatewayAssociationStateType",
     "GatewayTypeType",
     "GetAssociatedIpv6PoolCidrsPaginatorName",
     "GetGroupsForCapacityReservationPaginatorName",
@@ -712,6 +713,9 @@ FleetTypeType = Literal["instant", "maintain", "request"]
 FlowLogsResourceTypeType = Literal["NetworkInterface", "Subnet", "VPC"]
 FpgaImageAttributeNameType = Literal["description", "loadPermission", "name", "productCodes"]
 FpgaImageStateCodeType = Literal["available", "failed", "pending", "unavailable"]
+GatewayAssociationStateType = Literal[
+    "associated", "associating", "disassociating", "not-associated"
+]
 GatewayTypeType = Literal["ipsec.1"]
 GetAssociatedIpv6PoolCidrsPaginatorName = Literal["get_associated_ipv6_pool_cidrs"]
 GetGroupsForCapacityReservationPaginatorName = Literal["get_groups_for_capacity_reservation"]
